@@ -7,15 +7,19 @@ import time
 
 import grpc  # type: ignore
 from robot.api import logger  # type: ignore
+from robot.utils.robottime import timestr_to_secs  # type: ignore
 from robot.libraries.BuiltIn import BuiltIn  # type: ignore
 
-from Browser.generated.playwright_pb2 import Empty
+from Browser.generated.playwright_pb2 import Request
 import Browser.generated.playwright_pb2_grpc as playwright_pb2_grpc
 
 
 class Playwright:
     """A wrapper for communicating with nodejs Playwirght process."""
 
+    def __init__(self, timeout: str):
+        self.timeout = timeout
+
     @property
     def outputdir(self):
         return BuiltIn().get_variable_value("${OUTPUTDIR}")
@@ -33,6 +37,7 @@ class Playwright:
         port = str(self.find_free_port())
         env = dict(os.environ)
         env["PORT"] = port
+        env["TIMEOUT"] = str(float(timestr_to_secs(self.timeout)) * 1000)
         logger.info(f"Starting Browser process {playwright_script} using port {port}")
         self.port = port
         return Popen(
@@ -49,7 +54,7 @@ class Playwright:
             with grpc.insecure_channel(f"localhost:{self.port}") as channel:
                 try:
                     stub = playwright_pb2_grpc.PlaywrightStub(channel)
-                    response = stub.Health(Empty())
+                    response = stub.Health(Request().Empty())
                     logger.info(
                         f"Connected to the playwright process at port {self.port}: {response}"
                     )
